@@ -19,7 +19,7 @@
  * @author Haruki Setoyama <haruki@planewave.org>
  * @copyright Copyright &copy; 2003-2004, Haruki SETOYAMA <haruki@planewave.org>
  * @license http://www.opensource.org/licenses/lgpl-license.php LGPL
- * @version 0.4- $Id: phpoot.parser.php,v 1.16 2004/04/23 05:00:28 haruki Exp $
+ * @version 0.5- $Id: phpoot.parser.php,v 1.18 2004/04/27 02:34:00 haruki Exp $
  * @link http://phpoot.sourceforge.jp/
  * @package phpoot
  * @subpackage _parser
@@ -48,7 +48,7 @@ class phpoot_handler {
 
     /**
      * option
-	 * <pre>
+     * <pre>
      * 'escape''remove'     when true, remove all the <! ... >
      * 'pi''remove'         when true, remove all the <? ... ?>
      * 'jasp''remove'       when true, remove all the <% ... %>
@@ -56,42 +56,9 @@ class phpoot_handler {
      * 'tag''raw'           extention of model data with HTML.
      * 'tag''allow_no_brace'    variable name is normaly "{foo}" style. when true, allow just "foo"
      * </pre>
-	 * @var array
+     * @var array
      */
-    var $option = array(
-            'tag' => array(
-                'empty' => array(
-                    'br' => 1,
-                    'param' => 1,
-                    'hr' => 1,
-                    'input' => 1,
-                    'col' => 1,
-                    'img' => 1,
-                    'area' => 1,
-                    'frame' => 1,
-                    'meta' => 1,
-                    'link' => 1,
-                    'base' => 1,
-                    'basefont' => 1,
-                    'isindex' => 1
-                ),
-                'raw' => array(
-                    '_raw',
-                    '_html'
-                ),
-                'allow_no_brace' => false
-            ),
-			'data' => array(),
-            'escape' => array(
-                'remove' => false
-            ),
-            'pi' => array(
-                'remove' => true
-            ),
-            'jasp' => array(
-                'remove' => true
-            )
-        );
+    var $option;
 
     /**
      * template text
@@ -100,7 +67,6 @@ class phpoot_handler {
      */
     var $_template = '';
 
-
     /**
      * blanck phpoot_parser_tag object
      * @var array of phpoot_parser_tag
@@ -120,23 +86,52 @@ class phpoot_handler {
      * constructor
      * @access public
      */
-    function phpoot_handler($parsers = array('num', 'variable'))
+    function phpoot_handler(&$option, $parsers = array('num', 'variable'))
     {
+        // option
+        $default = array(
+            'tag' => array(
+                'empty' => array(
+                    'br' => 1,
+                    'param' => 1,
+                    'hr' => 1,
+                    'input' => 1,
+                    'col' => 1,
+                    'img' => 1,
+                    'area' => 1,
+                    'frame' => 1,
+                    'meta' => 1,
+                    'link' => 1,
+                    'base' => 1,
+                    'basefont' => 1,
+                    'isindex' => 1
+                ),
+                'raw' => array(),
+                'allow_no_brace' => false
+            ),
+            'data' => array(),
+            'escape' => array(
+                'remove' => false
+            ),
+            'pi' => array(
+                'remove' => true
+            ),
+            'jasp' => array(
+                'remove' => true
+            ),
+            '_merged' => 1
+        );
+        $this->option =& $option;
+        if (! isset($this->option['_merged'])) {
+            $this->option = array_merge_recursive($default, $this->option);
+        }
+    
         $this->_tag_parsers = array();
         foreach ($parsers as $parser) {
             $class = 'phpoot_parser_tag_' . $parser;
-            $this->_tag_parsers[] = new $class($this->option['tag']);
+            $this->_tag_parsers[] = new $class();
         }
-        $this->_tag_parsers[] = new phpoot_parser_tag_static($this->option['tag']);
-    }
-
-    /**
-     * set option by array
-     * @access public
-     */
-    function setOption($option)
-    {
-        $this->option = array_merge($this->option, $option);
+        $this->_tag_parsers[] = new phpoot_parser_tag_static();
     }
 
     /**
@@ -145,13 +140,21 @@ class phpoot_handler {
      */
     function init(&$template)
     {
-        $this->_level = 0;
-        $this->_error = array();
+        // template
         $template = str_replace(array("\r\n", "\r"), array("\n", "\n"), $template);
         $this->_template =& $template;
-
+        
+        // init private prop.
+        $this->_level = 0;
+        $this->_error = array();
         $this->_stack = array();
         $this->_stack[0] = new phpoot_parser_root;
+        
+        // option
+        $num = count($this->_tag_parsers);
+        for ($i=0; $i<$num; $i++) {
+            $this->_tag_parsers[$i]->setOption($this->option['tag']);
+        } 
     }
 
     /**
@@ -550,7 +553,11 @@ class phpoot_parser_tag extends phpoot_parser {
      */
     var $_delete = array('span' => 1);
 
-    function phpoot_parser_tag($option)
+    /**
+     * set option
+     * @access public
+     */
+    function setOption($option)
     {
         $this->_option = $option;
     }
