@@ -3,7 +3,7 @@ require_once '../phpoot.compiler.php';
 $compiler = new phpoot_compiler;
 $compiler->setErrorHandling(PEAR_ERROR_PRINT);
 $compiler->setTemplateDir('.');
-$removed = $compiler->removeCompiled('html');
+$removed = $compiler->removeAllCompiled('html');
 foreach ($removed as $file) {
 	echo $file.'<br />';
 }
